#!/usr/bin/env bash

# Author: Victor Correal (victor.correal@bsc.es)
# Date  : 13/10/2023 

source ../bash_utils/helpers.sh
source arg_parsing.sh

#INSTALLATION DIRs
MODEL_DIR=
SCRIPT_NAME=
OUTDIR="/gpfs/scratch/bsc32/$USER/RUNDIR"
INDIR="/gpfs/projects/bsc32/DestinE/inputs"
OTHER_VAR=
IO_ENABLED=true
#Derived:
BDIR=
RAPS_DIR=

#RESOURCES definition
NODES=DEFAULT
SLURM_SYNTAXIS_NODES=""
QUEUE=DEFAULT
SLURM_SYNTAXIS_QUEUE=""
TIME_LIMIT=DEFAULT
SLURM_SYNTAXIS_TIME_LIMIT=""
MPI_PER_NODE=DEFAULT
SLURM_SYNTAXIS_MPI_PER_NODE=""
OMP_PER_TASK=DEFAULT
SLURM_SYNTAXIS_OMP_PER_TASK=""

#SIMULATION SETUP
IO_ENABLED=true
FORCE_RUN=false
RESOLUTION=
IO_TASKS_IFS=16
IO_TASKS_NEMO=16
F_LENGHT="d5"
IO="noIO"

# parse arguments + user check(Y/N)
parse_args "$@"

# check dirs (RAPS_DIR, MODEL_DIR, SCRIPT_NAME)
check_required_args
check_dirs

OTHER_VAR="--ifs-bundle-build-dir=${BDIR} --experiment=hist --icmcl_79_2020 "
OTHER_VAR+="--nemo --nemo-ver=V40 --nemo-grid=eORCA1_Z75 --nonemopart -R --deep "
OTHER_VAR+="--keepfdb --iotasks=0 --nemo-multio-server-num=0 --multio-write-fdb " 
OTHER_VAR+="--keepnetcdf --nextgemsout=6 --wam-multio --ifs-multio "
#Check configurations

check_slurm_options
print_options

SUBMIT_DIR=$PWD
OUT_LOG="${SUBMIT_DIR}/${RESOLUTION}-${NODES}-${IO}-%j.out"

echo "Output log stored on: $OUT_LOG"

# SUBMIT SLURM JOB
cd $RAPS_DIR/bin/SLURM/mn5
sbatch  $SLURM_SYN_NODES \
        $SLURM_SYNTAXIS_QUEUE \
        $SLURM_SYNTAXIS_TIME_LIMIT \
        $SLURM_SYNTAXIS_MPI_PER_NODE \
        $SLURM_SYNTAXIS_OMP_PER_TASK \
        --exclusive \
        --export=other="${OTHER_VAR}",fclen="${F_LENGHT}",OUTROOT="${OUTDIR}",INPROOT="${INDIR}",ALL \
        --output=$OUT_LOG $SCRIPT_NAME
